==> kaidandashi-v3.2.1.zip: kaidandashi-v3.2.1/开单大师3.2.1学习版/install/templates/step1.php <==
<!doctype html>
<html>
	<!-- +~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	| 开单大师（专业的房产ERP管理系统）
	+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	| © 2019 http://www.kaidandashi.com All rights reserved.
	+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	| 本系统由淮南市银泰软件科技有限公司提供技术支持
	+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	| QQ号：984784483
	+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ -->
	<head>
		<meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
		<meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">
		<title>
			<?php echo $Title; ?> - <?php echo $Powered; ?>
		</title>
		<link rel="stylesheet" href="./css/install.css" />
	</head>
	<body>
		<div class="wrap">
			<?php require './templates/header.php';?>
			<div class="section">
				<div class="main cc">
					<pre class="pact" readonly="readonly">
《开单大师房产中介ERP》软件使用协议

版权所有 (c)2017-2050，银泰软件科技 保留所有权利。

感谢您选择《开单大师房产中介ERP》（简称“开单大师”），开单大师是国内最稳定、最强大、最先进的房产中介ERP解决方案之一，开单大师基于 PHP + MySQL 的技术，采用ThinkPHP框架开发。

为了使你正确并合法的使用本软件，请你在使用前务必阅读清楚下面的协议条款：

    本授权协议适用且仅适用于开单大师任何版本，开单大师官方对本授权协议的最终解释权和修改权。

    一、协议许可的权利

        1、您可以在完全遵守本最终用户授权协议的基础上，将本软件应用于非商业用途，而不必支付软件版权授权费用。

        2、您可以在协议规定的约束和限制范围内修改 开单大师 源代码或界面风格以适应您的网站要求。

        3、您拥有使用本软件构建的网站全部内容所有权，并独立承担与这些内容的相关法律义务。

        4、获得商业授权之后，您可以将本软件应用于商业用途，同时依据所购买的授权类型中确定的技术支持内容。商业授权用户享有反映和提出意见的权力，相关意见将被作为首要考虑，但没有一定被采纳的承诺或保证。

    二、协议许可的权利和限制

        1、未获商业授权之前，不得删除网站底部及相应的官方版权信息和链接。购买商业授权请联系银泰软件科技了解最新说明。开单大师著作权已在中华人民共和国国家版权局注册(中国国家版权局著作权登记号 2017SR409871)，著作权受到法律和国际公约保护。

        2、未经官方许可，不得对本软件或与之关联的商业授权进行出租、出售、抵押或发放子许可证。

        3、不管你的网站是否整体使用 开单大师 ，还是部份栏目使用 开单大师 ，在你使用了 开单大师 的网站主页上必须加上 开单大师 官方网址(www.kaidandashi.com)的链接。

        4、未经官方许可，禁止在 开单大师 的整体或任何部分基础上以发展任何派生版本、修改版本或第三方版本用于重新分发。

        5、如果您未能遵守本协议的条款，您的授权将被终止，所被许可的权利将被收回，并承担相应法律责任。

    三、有限担保和免责声明

        1、本软件及所附带的文件是作为不提供任何明确的或隐含的赔偿或担保的形式提供的。

        2、用户出于自愿而使用本软件，您必须了解使用本软件的风险，在尚未购买产品技术服务之前，我们不承诺对免费用户提供任何形式的技术支持、使用担保，也不承担任何因使用本软件而产生问题的相关责任。

        3、电子文本形式的授权协议如同双方书面签署的协议一样，具有完全的和等同的法律效力。您一旦开始确认本协议并安装 开单大师 ，即被视为完全理解并接受本协议的各项条款，在享有上述条款授予的权力的同时，受到相关的约束和限制。协议许可范围以外的行为，将直接违反本授权协议并构成侵权，我们有权随时终止授权，责令停止损害，并保留追究相关责任的权力。

协议发布时间：2017年6月22日

开单大师免费试用：http://reg.kaidandashi.com
开单大师演示地址：http://demo.kaidandashi.com
开单大师采购下单：http://reg.kaidandashi.com/index.php/dingdan/index
-----------------------------------------------------
运营团队：开单大师
联系电话：17095739404
官方邮箱：kdds888@163.com
官方网站：http://www.kaidandashi.com

					</pre>
				</div>
				<div class="bottom tac">
					<a href="<?php echo $_SERVER['PHP_SELF']; ?>?step=2" class="btn">接 受 协 议</a>
				</div>
			</div>
		</div>
		<?php require './templates/footer.php';?>
	</body>
</html>

==> kaidandashi_V4.6.8.zip: kaidandashi_V4.6.8/开单大师4.6.8学习版/install/templates/step1.php <==
<!doctype html>
<html>
	<!-- +~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	| 开单大师（专业的房产中介管理系统）
	+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	| © 2017-2023 http://www.kaidandashi.com/ All rights reserved
	+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	| 本系统由淮南市银泰软件科技有限公司提供技术支持
	+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	| QQ号：984784483
	+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ -->
	<head>
		<meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
		<meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">
		<title>
			<?php echo $Title; ?> - <?php echo $Powered; ?>
		</title>
		<link rel="stylesheet" href="./css/install.css" />
	</head>
	<body>
		<div class="wrap">
			<?php require './templates/header.php';?>
			<div class="section">
				<div class="main cc">
					<pre class="pact" readonly="readonly">
《开单大师房产中介ERP》软件使用协议

版权所有 © 2017-2067 淮南市银泰软件科技有限公司 保留所有权利。

感谢您选择《开单大师房产中介ERP》（简称“开单大师”），开单大师是国内最稳定、最强大、最先进的房产中介ERP解决方案之一，开单大师基于 PHP + MySQL 的技术，采用ThinkPHP框架开发。

为了使你正确并合法的使用本软件，请你在使用前务必阅读清楚下面的协议条款：

    本授权协议适用且仅适用于开单大师任何版本，开单大师官方对本授权协议的最终解释权和修改权。

    一、协议许可的权利

        1、您可以在完全遵守本最终用户授权协议的基础上，将本软件应用于非商业用途，而不必支付软件版权授权费用。

        2、您可以在协议规定的约束和限制范围内修改 开单大师 源代码或界面风格以适应您的网站要求。

        3、您拥有使用本软件构建的网站全部内容所有权，并独立承担与这些内容的相关法律义务。

        4、获得商业授权之后，您可以将本软件应用于商业用途，同时依据所购买的授权类型中确定的技术支持内容。商业授权用户享有反映和提出意见的权力，相关意见将被作为首要考虑，但没有一定被采纳的承诺或保证。

    二、协议许可的权利和限制

        1、未获商业授权之前，不得删除网站底部及相应的官方版权信息和链接。购买商业授权请联系淮南市银泰软件科技有限公司了解最新说明。开单大师著作权已在中华人民共和国国家版权局注册（中国国家版权局著作权登记号 2017SR409871），著作权受到法律和国际公约保护。

        2、未经官方许可，不得对本软件或与之关联的商业授权进行出租、出售、抵押或发放子许可证。

        3、不管你的网站是否整体使用 开单大师 ，还是部份栏目使用 开单大师 ，在你使用了 开单大师 的网站主页上必须加上 开单大师 官方网址（http://www.kaidandashi.com）的链接。

        4、未经官方许可，禁止在 开单大师 的整体或任何部分基础上以发展任何派生版本、修改版本或第三方版本用于重新分发。

        5、如果您未能遵守本协议的条款，您的授权将被终止，所被许可的权利将被收回，并承担相应法律责任。

    三、有限担保和免责声明

        1、本软件及所附带的文件是作为不提供任何明确的或隐含的赔偿或担保的形式提供的。

        2、用户出于自愿而使用本软件，您必须了解使用本软件的风险，在尚未购买产品技术服务之前，我们不承诺对免费用户提供任何形式的技术支持、使用担保，也不承担任何因使用本软件而产生问题的相关责任。

        3、电子文本形式的授权协议如同双方书面签署的协议一样，具有完全的和等同的法律效力。您一旦开始确认本协议并安装 开单大师 ，即被视为完全理解并接受本协议的各项条款，在享有上述条款授予的权力的同时，受到相关的约束和限制。协议许可范围以外的行为，将直接违反本授权协议并构成侵权，我们有权随时终止授权，责令停止损害，并保留追究相关责任的权力。

协议发布时间：2017年6月22日

开单大师演示地址：https://demozxb.kaidandashi.com/
-----------------------------------------------------
运营团队：开单大师
联系电话：19965783436
官方邮箱：342450366@qq.com
官方网站：http://www.kaidandashi.com/

					</pre>
				</div>
				<div class="bottom tac">
					<a href="<?php echo $_SERVER['PHP_SELF']; ?>?step=2" class="btn">接 受 协 议</a>
				</div>
			</div>
		</div>
		<?php require './templates/footer.php';?>
		<script type="text/javascript" src="http://51la.kaidandashi.com/20167797.js"></script>
		<script>
			var _hmt = _hmt || [];
			(function() {
				var hm = document.createElement("script");
				hm.src = "https://hm.baidu.com/hm.js?2a79f6e272ec7c88f6cb01da90e36bf3";
				var s = document.getElementsByTagName("script")[0]; 
				s.parentNode.insertBefore(hm, s);
			})();
		</script>
	</body>
</html>
